==> apertium-fra-frp_1.0.0.orig.tar.bz2: apertium-fra-frp-1.0.0/apertium-frp-1.0.0/README.md <==
frp: `apertium-frp`
===============================================================================

This is an Apertium monolingual language package for Arpitan. What
you can use this language package for:

* Morphological analysis of Arpitan
* Morphological generation of Arpitan
* Part-of-speech tagging of Arpitan

Requirements
-------------------------------------------------------------------------------

You will need the following software installed:

* lttoolbox (>= 3.3.0)
* apertium (>= 3.3.0)
* vislcg3 (>= 0.9.9.10297)

If this does not make any sense, we recommend you look at: www.apertium.org.

Compiling
-------------------------------------------------------------------------------

Given the requirements being installed, you should be able to just run:

```bash
$ ./configure
$ make
```

You can use `./autogen.sh` instead of `./configure` if you're compiling
from source.

If you're doing development, you don't have to install the data, you
can use it directly from this directory.

If you are installing this language package as a prerequisite for an
Apertium translation pair, then do (typically as root / with sudo):

```console
# make install
```

You can use a `--prefix` with `./configure` to install as a non-root user,
but make sure to use the same prefix when installing the translation
pair and any other language packages.

Testing
-------------------------------------------------------------------------------

If you are in the source directory after running make, the following
commands should work:

```console
$ echo "TODO: test sentence" | apertium -d . frp-morph
TODO: test analysis result

$ echo "TODO: test sentence" | apertium -d . frp-tagger
TODO: test tagger result
```

Files and data
-------------------------------------------------------------------------------

* [`apertium-frp.frp.metadix`](apertium-frp.frp.metadix) - Monolingual dictionary
* [`frp.prob`](frp.prob) - Tagger model
* [`apertium-frp.frp.rlx`](apertium-frp.frp.rlx) - Constraint Grammar disambiguation rules
* [`apertium-frp.post-frp.dix`](apertium-frp.post-frp.dix) - Post-generator
* [`modes.xml`](modes.xml) - Translation modes

For more information
-------------------------------------------------------------------------------

* http://wiki.apertium.org/wiki/Installation
* http://wiki.apertium.org/wiki/apertium-frp
* http://wiki.apertium.org/wiki/Using_an_lttoolbox_dictionary

Help and support
-------------------------------------------------------------------------------

If you need help using this language pair or data, you can contact:

* Mailing list: apertium-stuff@lists.sourceforge.net
* IRC: `#apertium` on irc.freenode.net (irc://irc.freenode.net/#apertium)

See also the file [`AUTHORS`](AUTHORS), included in this distribution.

==> apertium-fra-frp_1.1.0.orig.tar.bz2: apertium-fra-frp-1.1.0/apertium-frp-1.1.0/README.md <==
frp: `apertium-frp`
===============================================================================

This is an Apertium monolingual language package for Arpitan. What
you can use this language package for:

* Morphological analysis of Arpitan
* Morphological generation of Arpitan
* Part-of-speech tagging of Arpitan

Requirements
-------------------------------------------------------------------------------

You will need the following software installed:

* lttoolbox (>= 3.3.0)
* apertium (>= 3.3.0)
* vislcg3 (>= 0.9.9.10297)

If this does not make any sense, we recommend you look at: apertium.org.

Compiling
-------------------------------------------------------------------------------

Given the requirements being installed, you should be able to just run:

```bash
$ ./configure
$ make
```

You can use `./autogen.sh` instead of `./configure` if you're compiling
from source.

If you're doing development, you don't have to install the data, you
can use it directly from this directory.

If you are installing this language package as a prerequisite for an
Apertium translation pair, then do (typically as root / with sudo):

```console
# make install
```

You can use a `--prefix` with `./configure` to install as a non-root user,
but make sure to use the same prefix when installing the translation
pair and any other language packages.

Testing
-------------------------------------------------------------------------------

If you are in the source directory after running make, the following
commands should work:

```console
$ echo "TODO: test sentence" | apertium -d . frp-morph
TODO: test analysis result

$ echo "TODO: test sentence" | apertium -d . frp-tagger
TODO: test tagger result
```

Files and data
-------------------------------------------------------------------------------

* [`apertium-frp.frp.metadix`](apertium-frp.frp.metadix) - Monolingual dictionary
* [`frp.prob`](frp.prob) - Tagger model
* [`apertium-frp.frp.rlx`](apertium-frp.frp.rlx) - Constraint Grammar disambiguation rules
* [`apertium-frp.post-frp.dix`](apertium-frp.post-frp.dix) - Post-generator
* [`modes.xml`](modes.xml) - Translation modes

For more information
-------------------------------------------------------------------------------

* https://wiki.apertium.org/wiki/Installation
* https://wiki.apertium.org/wiki/apertium-frp
* https://wiki.apertium.org/wiki/Using_an_lttoolbox_dictionary

Help and support
-------------------------------------------------------------------------------

If you need help using this language pair or data, you can contact:

* Mailing list: apertium-stuff@lists.sourceforge.net
* IRC: `#apertium` on irc.oftc.net (irc://irc.oftc.net/#apertium)

See also the file [`AUTHORS`](AUTHORS), included in this distribution.
